@@ -64,10 +64,9 @@ using std::make_pair;
 
 typedef queue< vector< string > > MessageQueue;
 
-static void sendSocketMessage(int socket, const vector< string >& message)
+static void sendRawSocketMessage(int socket, const string& compactedMessage)
 {
-	auto compactedMessage = join("\1", message);
-	if (message.size() >= 0xFFFF)
+	if (compactedMessage.size() >= 0xFFFF)
 	{
 		fatal2i("sendSocketMessage: message size exceeded 64K");
 	}
@@ -80,6 +79,11 @@ static void sendSocketMessage(int socket, const vector< string >& message)
 	}
 }
 
+static void sendSocketMessage(int socket, const vector< string >& message)
+{
+	sendRawSocketMessage(socket, join("\1", message));
+}
+
 static void sendSocketMessage(Pipe& pipe, const vector< string >& message)
 {
 	sendSocketMessage(pipe.getWriterFd(), message);
@@ -325,9 +329,10 @@ volatile sig_atomic_t pingIsProcessed = true;
 
 void sendPingMessage(int)
 {
+	static const string pingMessage = "ping";
 	if (pingIsProcessed) // don't send a ping when last is not processed
 	{
-		sendSocketMessage(pingPipe, vector< string >{ "ping" });
+		sendRawSocketMessage(pingPipe.getWriterFd(), pingMessage);
 	}
 	pingIsProcessed = false;
 }
